bearermanagement/mpm/inc/mpmserver.h
changeset 18 fcbbe021d614
parent 3 f7816ffc66ed
child 20 9c97ad6591ae
--- a/bearermanagement/mpm/inc/mpmserver.h	Tue Feb 02 00:24:11 2010 +0200
+++ b/bearermanagement/mpm/inc/mpmserver.h	Fri Apr 16 15:21:37 2010 +0300
@@ -37,6 +37,7 @@
 
 class CMPMCommsDatAccess;
 class CMpmCsIdWatcher;
+class CMpmDataUsageWatcher;
 
 // CONSTANTS
 _LIT( KMPMPanicCategory, "Mobility Policy Manager Server" );
@@ -124,7 +125,8 @@
 // Which component initiated sending preferred IAP notifications
 enum TPrefIAPNotifCaller
     {
-    EConnMon = 0, 
+    EConnMon = 0,
+    EConnMonEvent,
     EBearerMan, 
     EConfirmDlgRoaming, 
     EConfirmDlgStarting
@@ -436,9 +438,11 @@
         /**
         * Notify each session about IAP availability change.
         * @since 3.1
         * @param aIapInfo Info about available IAPs 
         */
-        void NotifyBMPrefIapL( const TConnMonIapInfo& aIapInfo );
+        void NotifyBMPrefIapL( const TConnMonIapInfo& aIapInfo,
+                               const TPrefIAPNotifCaller aCaller );
 
         /**
         * Update Connection dialog of each session
@@ -488,17 +492,6 @@
         /**
         * Handling of unblacklisting all IAPs for certain category.
         * @since 3.2
-        * @param aConnId Connection Id
-        * @param aCategory Either connection lifetime or temporary. 
-        * @return KErrNone if successful, otherwise one of the
-        * system-wide error codes 
-        */
-        TInt HandleServerUnblackListIap( const TConnectionId aConnId, 
-                                         TBlacklistCategory  aCategory );
-
-        /**
-        * Handling of unblacklisting all IAPs for certain category.
-        * @since 3.2
         * @param aCategory Either connection lifetime or temporary. 
         */
         void HandleServerUnblackListIap( TBlacklistCategory  aCategory );
@@ -834,6 +827,12 @@
         */
         CMPMServerSession* GetServerSession( TConnectionId aConnId ) const;
         
+        /**
+        * Stops cellular connections, except MMS
+        * @since 5.2
+        */
+        void StopCellularConns();
+
     private:
 
         /**
@@ -938,6 +937,11 @@
          */
         CMpmCsIdWatcher* iMpmCsIdWatcher;
 
+        /**
+         * Handle to another central repository watcher
+         */
+        CMpmDataUsageWatcher* iMpmDataUsageWatcher;
+
         // Iap id of the active connection
         TUint32 iActiveIapId;
@@ -436,9 +438,11 @@
         * Notify each session about IAP availability change.
         * @since 3.1
-        * @param aIapInfo Info about available IAPs 
+        * @param aIapInfo Info about available IAPs
+        * @param aCaller Identifies the calling context 
         */